@@ -46,6 +46,7 @@ typedef enum {
 } SubmitType;
 
 typedef enum {
+	STATE_INTRO,
 	STATE_GDB,
 	STATE_PRODUCT,
 	STATE_COMPONENT,
@@ -57,12 +58,16 @@ typedef enum {
 	STATE_LAST
 } BuddyState;
 
-typedef struct {
-	const char *name;
-	const char *command;
-	gboolean    start_in_terminal;
-	gboolean    use_moz_remote;
-} MailerItem;
+typedef enum {
+	BUG_CRASH,
+	BUG_DEBUG,
+	BUG_WRONG,
+	BUG_I18N,
+	BUG_DOC,
+	BUG_REQUEST
+} BugType;
+
+
 
 typedef struct {
 	/* contact page */
@@ -88,6 +93,10 @@ extern PoptData popt_data;
 typedef struct {
 	GladeXML  *xml;
 	BuddyState state;
+	BugType bug_type;
+	gboolean	product_skipped;
+	gboolean	component_skipped;
+	gboolean	mostfreq_skipped;
 
 	/* canvas stuff */
 	GnomeCanvasItem *title_box;
@@ -104,9 +113,6 @@ typedef struct {
 
 	gboolean already_run;
 
-#if 0
-	Distribution      *distro;
-#endif
 	char              *bts_file;
 
 	CrashType  crash_type;
@@ -114,6 +120,9 @@ typedef struct {
 	int selected_row;
 	int progress_timeout;
 
+
+	char      *distro;
+	
 	/* gdb stuff */
 	pid_t       app_pid;
 	pid_t       gdb_pid;
@@ -121,16 +130,13 @@ typedef struct {
 	int         fd;
 	gboolean    explicit_dirty;
 
-	BugzillaBTS *all_products;
-	GSList      *bugzillas;
+	GHashTable  *bugzillas;
+	GSList *applications;
+	GHashTable *program_to_application;
+	char *current_appname;
 
 	/* Debian BTS stuff */
 	SubmitType    submit_type;
-#if 0
-	BugType       bug_type; 
-	SeverityType  severity;
-	BugClassType  bug_class;
-#endif
 	GSList       *packages;
 
 	GSList       *bugs;
@@ -143,6 +149,7 @@ typedef struct {
 	GList *dlsources;
 	GList *dldests;
 
+	int last_update_check;
 	gboolean download_in_progress;
 
 	GnomeVFSAsyncHandle *vfshandle;
@@ -153,11 +160,12 @@ typedef struct {
 
 	const char *gnome_version;
 
-	GHashTable *mailer_hash;
-	MailerItem *mailer;
-	MailerItem  custom_mailer;
+	char *gnome_platform_version;
+	char *gnome_distributor;
 
 	guint dl_timeout;
+
+	gboolean show_products;
 } DruidData;
 
 extern DruidData druid_data;
