@@ -25,6 +25,7 @@
 #include "libglade-buddy.h"
 #include "cell-renderer-uri.h"
 #include "md5-utils.h"
+#include "distribution.h"
 
 #include <sys/stat.h>
 #include <sys/types.h>
@@ -1217,9 +1218,7 @@ add_product (gpointer key, BugzillaProduct *p, GtkListStore *store)
 static void
 add_products (gpointer key, BugzillaBTS *bts, GtkListStore *store)
 {
-	if (bts->products != NULL) {
-		g_hash_table_foreach (bts->products, (GHFunc)add_product, store);
-	}
+	g_hash_table_foreach (bts->products, (GHFunc)add_product, store);
 }
 
 static void
@@ -1419,10 +1418,13 @@ generate_email_text (gboolean include_headers)
 	g_free (s);
 
 	severity = druid_data.severity ? druid_data.severity : "Normal";
-
+	
 	if (include_headers)
 		g_string_append_printf (email, "Subject: %s\n\n", subject);
 
+	get_distro_name();
+	if (druid_data.distro)
+		g_string_append_printf (email, "Distribution: %s\n", druid_data.distro);
 	if (!is_bugzilla) {
 		g_string_append (email, "(This bug report was generated by Bug Buddy " VERSION ")\n");
 	} else if (druid_data.product->bts->submit_type == BUGZILLA_SUBMIT_DEBIAN) {
@@ -1434,11 +1436,15 @@ generate_email_text (gboolean include_headers)
 					? druid_data.gnome_platform_version
 					: "",
 					version);
-		if (druid_data.gnome_vendor)
-			g_string_append_printf (email, "os_details: %s\n", druid_data.gnome_vendor);
+		if (druid_data.gnome_distributor)
+			g_string_append_printf (email, "Gnome distributor: %s\n", druid_data.gnome_distributor);
 		g_string_append_printf (email, "Synopsis: %s\n", subject);
 		g_string_append_printf (email, "Bugzilla-Product: %s\n", druid_data.product->name);
 		g_string_append_printf (email, "Bugzilla-Component: %s\n", druid_data.component->name);
+		if (druid_data.bug_type == BUG_DOC)
+			g_string_append_printf (email, "Bugzilla-Keyword: doc\n");
+		if (druid_data.bug_type == BUG_I18N)
+			g_string_append_printf (email, "Bugzilla-Keyword: i18n\n");
 		if (druid_data.gnome_version)
 			g_string_append_printf (email, "BugBuddy-GnomeVersion: %s\n", druid_data.gnome_version);
 		g_string_append (email, "Description:\n");
